@@ -25,7 +25,7 @@ def load_trigram_file(f):
         for line in file_handle:
             l = line.strip().split("\t")
             words = l[0].split(" ")
-            trgs.append([Trigram(word=words[-1],word_i_minus_one=words[1],word_i_minus_two=words[0],count=int(l[1]))])
+            trgs.append(Trigram(word=words[-1],word_i_minus_one=words[1],word_i_minus_two=words[0],count=int(l[1])))
             if len(trgs) > 100000:
                 Trigram.objects.bulk_create(trgs)
                 trgs = []
